==> create-fly-1.21.8-6.0.8-2-sources.jar: com/zurrtum/create/client/content/kinetics/deployer/DeployerFilterSlot.java <==
package com.zurrtum.create.client.content.kinetics.deployer;

import com.zurrtum.create.catnip.math.AngleHelper;
import com.zurrtum.create.catnip.math.VecHelper;
import com.zurrtum.create.client.flywheel.lib.transform.TransformStack;
import com.zurrtum.create.client.foundation.blockEntity.behaviour.ValueBoxTransform;
import com.zurrtum.create.content.kinetics.deployer.DeployerBlock;
import net.minecraft.class_1936;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2350.class_2351;
import net.minecraft.class_243;
import net.minecraft.class_2680;
import net.minecraft.class_4587;

public class DeployerFilterSlot extends ValueBoxTransform.Sided {

    @Override
    public class_243 getLocalOffset(class_1936 level, class_2338 pos, class_2680 state) {
        class_2350 facing = state.method_11654(DeployerBlock.FACING);
        class_243 vec = VecHelper.voxelSpace(8f, 8f, 15.5f);

        vec = VecHelper.rotateCentered(vec, AngleHelper.horizontalAngle(getSide()), class_2351.field_11052);
        vec = VecHelper.rotateCentered(vec, AngleHelper.verticalAngle(getSide()), class_2351.field_11048);
        vec = vec.method_1020(class_243.method_24954(facing.method_62675()).method_1021(2 / 16f));

        return vec;
    }

    @Override
    protected boolean isSideActive(class_2680 state, class_2350 direction) {
        class_2350 facing = state.method_11654(DeployerBlock.FACING);
        if (direction.method_10166() == facing.method_10166())
            return false;
        if (((DeployerBlock) state.method_26204()).getRotationAxis(state) == direction.method_10166())
            return false;
        return true;
    }

    @Override
    public void rotate(class_1936 level, class_2338 pos, class_2680 state, class_4587 ms) {
        class_2350 facing = getSide();
        float xRot = facing == class_2350.field_11036 ? 90 : facing == class_2350.field_11033 ? 270 : 0;
        float yRot = AngleHelper.horizontalAngle(facing) + 180;

        if (facing.method_10166() == class_2351.field_11052)
            TransformStack.of(ms).rotateYDegrees(180 + AngleHelper.horizontalAngle(state.method_11654(DeployerBlock.FACING)));

        TransformStack.of(ms).rotateYDegrees(yRot).rotateXDegrees(xRot);
    }

    @Override
    protected class_243 getSouthLocation() {
        return class_243.field_1353;
    }

}

==> create-fly-1.21.11-pre1-6.0.8-1-sources.jar: com/zurrtum/create/client/content/kinetics/deployer/DeployerFilterSlot.java <==
package com.zurrtum.create.client.content.kinetics.deployer;

import com.zurrtum.create.catnip.math.AngleHelper;
import com.zurrtum.create.catnip.math.VecHelper;
import com.zurrtum.create.client.flywheel.lib.transform.TransformStack;
import com.zurrtum.create.client.foundation.blockEntity.behaviour.ValueBoxTransform;
import com.zurrtum.create.content.kinetics.deployer.DeployerBlock;
import net.minecraft.class_2350;
import net.minecraft.class_2350.class_2351;
import net.minecraft.class_243;
import net.minecraft.class_2680;
import net.minecraft.class_4587;

public class DeployerFilterSlot extends ValueBoxTransform.Sided {

    @Override
    public class_243 getLocalOffset(class_2680 state) {
        class_2350 facing = state.method_11654(DeployerBlock.FACING);
        class_243 vec = VecHelper.voxelSpace(8f, 8f, 15.5f);

        vec = VecHelper.rotateCentered(vec, AngleHelper.horizontalAngle(getSide()), class_2351.field_11052);
        vec = VecHelper.rotateCentered(vec, AngleHelper.verticalAngle(getSide()), class_2351.field_11048);
        vec = vec.method_1020(class_243.method_24954(facing.method_62675()).method_1021(2 / 16f));

        return vec;
    }

    @Override
    protected boolean isSideActive(class_2680 state, class_2350 direction) {
        class_2350 facing = state.method_11654(DeployerBlock.FACING);
        if (direction.method_10166() == facing.method_10166())
            return false;
        if (((DeployerBlock) state.method_26204()).getRotationAxis(state) == direction.method_10166())
            return false;
        return true;
    }

    @Override
    public void rotate(class_2680 state, class_4587 ms) {
        class_2350 facing = getSide();
        float xRot = facing == class_2350.field_11036 ? 90 : facing == class_2350.field_11033 ? 270 : 0;
        float yRot = AngleHelper.horizontalAngle(facing) + 180;

        if (facing.method_10166() == class_2351.field_11052)
            TransformStack.of(ms).rotateYDegrees(180 + AngleHelper.horizontalAngle(state.method_11654(DeployerBlock.FACING)));

        TransformStack.of(ms).rotateYDegrees(yRot).rotateXDegrees(xRot);
    }

    @Override
    protected class_243 getSouthLocation() {
        return class_243.field_1353;
    }

}
